@@ -15,7 +15,7 @@ use URI::Escape qw{uri_escape_utf8};
 # of ExtUtils::MakeMaker->WriteMakefile() will accurately detect $VERSION.
 #
 my
-$VERSION = '1.000008';
+$VERSION = '1.000009';
 
 #
 # See https://tech.yandex.ru/translate/doc/dg/concepts/api-overview-docpage/
@@ -257,7 +257,7 @@ Yandex::Translate - a simple API for Yandex.Translate
 
 =head1 VERSION
 
-version 1.000008
+version 1.000009
 
 =head1 SYNOPSIS
 
@@ -458,7 +458,7 @@ L<https://fossil.falseking.site/ticket>
 This is open source software. The code repository is available for
 public review and contribution under the terms of the license.
 
-L<https://fossil.falseking.site/dir?ci=cdaf55ce8487865d&name=Yandex-Translate&type=tree>
+L<https://fossil.falseking.site/dir?ci=tip&type=tree>
 
 =head1 AUTHORS
 
